@@ -25,8 +25,8 @@
 
 #ifndef COMMAND_INCLUDED
 #define COMMAND_INCLUDED
-#include <system/Process.h>
-#include <util/List.h>
+#include "system/Process.h"
+#include "util/List.h"
 
 
 /**
@@ -49,11 +49,6 @@
 
 #define T Command_T
 typedef struct T *T;
-/** 
- * Default Path for Command: <code>PATH=/bin:/usr/bin:/usr/local/bin:/opt/csw/bin:/usr/sfw/bin</code>. 
- * May be overridden by Command_setEnv() 
- */
-extern const char *Command_Path;
 
 
 /**
@@ -91,6 +86,15 @@ void Command_free(T *C);
 /** @name Properties */
 //@{
 
+
+/**
+ * Append an argument to the command that should be used to launch this executable.
+ * @param C A Command object
+ * @param argument A string argument
+ */
+void Command_appendArgument(T C, const char *argument);
+
+
 /**
  * Set the user id the sub-process should switch to on exec. If not set, the uid of 
  * the calling process is used. Note that this process must run with super-user
@@ -154,8 +158,9 @@ const char *Command_getDir(T C);
 
 /**
  * Set or replace the environment variable identified by <code>name</code>.
- * The sub-process does <em>not</em> inherit the environment from the calling 
- * process and has only a spartan PATH set by default.
+ * The sub-process initially inherits the environment from the calling process.
+ * Environment variables set with this method does not affect the parent 
+ * process and only apply to the sub-process.
  * @param C A Command object
  * @param name The environment variable to set or replace
  * @param value The value
@@ -163,19 +168,6 @@ const char *Command_getDir(T C);
 void Command_setEnv(T C, const char *name, const char *value);
 
 
-/**
- * Set or replace the environment variable(s) specified in <code>env</code>.
- * The <code>env</code> string is expected to be on a name=value; format
- * and each name=value pair must be separated with ';'. This is a
- * convenience function, wrapping Command_setEnv() and is rather inefficient.
- * @param C A Command object
- * @param env An environment string containing name=value pairs separated 
- * with ';'. Example: <code>PATH=/usr/bin; SHELL=/bin/bash;</code>
- * @see Command_setEnv()
- */
-void Command_vSetEnv(T C, const char *env, ...);
-
-
 /**
  * Returns the value of the environment variable identified by 
  * <code>name</code>. 
@@ -209,7 +201,7 @@ List_T Command_getCommand(T C);
  * Process_T object by calling Process_free(). If creating the new 
  * sub-process failed, NULL is returned and errno is set to indicate the
  * error. Use e.g. System_getLastError() to get a description of the error
- * that occured.
+ * that occurred.
  * @param C A Command object
  * @return A new Process_T object representing the sub-process or NULL
  * if execute failed.
