@@ -70,14 +70,12 @@
 
 
 int Net_setNonBlocking(int socket) {
-        int  on = 1;
-        return (ioctl(socket, FIONBIO, &on) != -1);
+        return (fcntl(socket, F_SETFL, fcntl(socket, F_GETFL, 0) | O_NONBLOCK) != -1);
 }
 
 
 int Net_setBlocking(int socket) {
-        int  off = 0;
-        return (ioctl(socket, FIONBIO, &off) != -1);
+        return (fcntl(socket, F_SETFL, fcntl(socket, F_GETFL, 0) & ~O_NONBLOCK) != -1);
 }
 
 
@@ -105,7 +103,7 @@ int Net_canWrite(int socket, time_t milliseconds) {
 }
 
 
-size_t Net_read(int socket, void *buffer, size_t size, time_t timeout) {
+ssize_t Net_read(int socket, void *buffer, size_t size, time_t timeout) {
 	ssize_t n = 0;
         if (size > 0) {
                 do {
@@ -123,7 +121,7 @@ size_t Net_read(int socket, void *buffer, size_t size, time_t timeout) {
 }
 
 
-size_t Net_write(int socket, const void *buffer, size_t size, time_t timeout) {
+ssize_t Net_write(int socket, const void *buffer, size_t size, time_t timeout) {
 	ssize_t n = 0;
         if (size > 0) {
                 do {
@@ -139,3 +137,28 @@ size_t Net_write(int socket, const void *buffer, size_t size, time_t timeout) {
         }
 	return n;
 }
+
+
+int Net_shutdown(int socket, int how) {
+        return (shutdown(socket, how) == 0);
+}
+
+
+int Net_close(int socket) {
+	int r = 0;
+        do {
+                r = close(socket);
+        } while (r == -1 && errno == EINTR);
+	return (r == 0);
+}
+
+
+int Net_abort(int socket) {
+   	int r;
+        struct linger linger = {1, 0};
+        setsockopt(socket, SOL_SOCKET, SO_LINGER, &linger, sizeof linger);
+        do {
+                r = close(socket);
+        } while (r == -1 && errno == EINTR);
+	return (r == 0);
+}
