@@ -210,10 +210,8 @@ int Str_startsWith(const char *a, const char *b) {
 
 int Str_endsWith(const char *a, const char *b) {
         if (a && b) {
-                register int i = 0, j = 0;
-                while (a[i]) i++;
-                while (b[j]) j++;
-                for(; (i && j); i--, j--)
+                size_t i = 0, j = 0;
+                for(i = strlen(a), j = strlen(b); (i && j); i--, j--)
                         if(toupper(a[i]) != toupper(b[j])) return false;
                 return (i >= j);
         }
@@ -223,15 +221,15 @@ int Str_endsWith(const char *a, const char *b) {
 
 char *Str_sub(const char *a, const char *b) {
         if (a && STR_DEF(b)) {
-                const char *ap, *bp;
+                const char *p, *q;
                 while (*a) {
                         if (toupper(*a) == toupper(*b)) {
-                                ap = a;
-                                bp = b;
+                                p = a;
+                                q = b;
                                 do
-                                        if (! *bp)
+                                        if (! *q)
                                                 return (char*)a;
-                                while (toupper(*ap++) == toupper(*bp++));
+                                while (toupper(*p++) == toupper(*q++));
                         }
                         a++;
                 }
@@ -289,10 +287,9 @@ char *Str_copy(char *dest, const char *src, int n) {
 char *Str_dup(const char *s) { 
         char *t = NULL;
         if (s) {
-                size_t n = strlen(s); 
-                t = ALLOC(n + 1);
+                size_t n = strlen(s) + 1;
+                t = ALLOC(n);
                 memcpy(t, s, n);
-                t[n] = 0;
         }
         return t;
 }
@@ -302,7 +299,7 @@ char *Str_ndup(const char *s, long n) {
         char *t = NULL;
         assert(n >= 0);
         if (s) {
-                size_t l = strlen(s); 
+                size_t l = strlen(s);
                 n = l < n ? l : n; // Use the actual length of s if shorter than n
                 t = ALLOC(n + 1);
                 memcpy(t, s, n);
@@ -340,19 +337,14 @@ char *Str_cat(const char *s, ...) {
 char *Str_vcat(const char *s, va_list ap) {
         char *t = NULL;
         if (s) {
-                int n = 0;
                 va_list ap_copy;
-                int size = STRLEN;
+                va_copy(ap_copy, ap);
+                int size = vsnprintf(t, 0, s, ap_copy) + 1;
+                va_end(ap_copy);
                 t = ALLOC(size);
-                while (true) {
-                        va_copy(ap_copy, ap);
-                        n = vsnprintf(t, size, s, ap_copy);
-                        va_end(ap_copy);
-                        if (n < size)
-                                break;
-                        size = n + 1;
-                        RESIZE(t, size);
-                }
+                va_copy(ap_copy, ap);
+                vsnprintf(t, size, s, ap_copy);
+                va_end(ap_copy);
         }
         return t;
 }
