@@ -71,6 +71,20 @@ static void onKill(Process_T P) {
 }
 
 
+static void onEnv(Process_T P) {
+        assert(P);
+        char buf[STRLEN];
+        InputStream_T in = Process_getInputStream(P);
+        assert(InputStream_readLine(in, buf, STRLEN));
+        assert(Str_isEqual(Str_chomp(buf), "Ylajali"));
+        // Assert that sub-process environment is not set in main process
+        assert(! getenv("SULT"));
+        printf("\tEnvironment Variable in sub-process only: $SULT = %s\n", buf);
+        Process_free(&P);
+        assert(! P);
+}
+
+
 int main(void) {
 
         Bootstrap(); // Need to initialize library
@@ -136,34 +150,20 @@ int main(void) {
         {
                 Command_T c = Command_new("/bin/sh", "-c", "ps -aef|grep monit", NULL);
                 assert(c);
-                // Check default PATH
-                assert(Str_isEqual(Command_getEnv(c, "PATH"), "/bin:/usr/bin:/usr/local/bin:/opt/csw/bin:/usr/sfw/bin"));
-                // Set and get
-                Command_setEnv(c, "LANG", "C");
-                assert(Str_isEqual(Command_getEnv(c, "LANG"), "C"));
-                Command_setEnv(c, "SHELL", "/bin/bash");
-                assert(Str_isEqual(Command_getEnv(c, "SHELL"), "/bin/bash"));
-                // setEnvString
-                // Check default PATH
-                assert(Str_isEqual(Command_getEnv(c, "PATH"), "/bin:/usr/bin:/usr/local/bin:/opt/csw/bin:/usr/sfw/bin"));
                 // Set and get env string
-                Command_vSetEnv(c, "PATH=/usr/bin;SHELL=/bin/bash");
+                Command_setEnv(c, "PATH", "/usr/bin");
+                Command_setEnv(c, "SHELL", "/bin/bash");
+                Command_setEnv(c, "PAT", "Carroll");
                 assert(Str_isEqual(Command_getEnv(c, "PATH"), "/usr/bin"));
                 assert(Str_isEqual(Command_getEnv(c, "SHELL"), "/bin/bash"));
-                // With space in string
-                Command_vSetEnv(c, "LANG = C");
-                assert(Str_isEqual(Command_getEnv(c, "LANG"), "C"));
-                Command_vSetEnv(c, "PATH = /usr/bin ; SHELL = /bin/bash");
-                assert(Str_isEqual(Command_getEnv(c, "PATH"), "/usr/bin"));
-                assert(Str_isEqual(Command_getEnv(c, "SHELL"), "/bin/bash"));
-                // Invalid String
-                Command_vSetEnv(c, "HELLO:WORLD");
-                assert(! Command_getEnv(c, "HELLO"));
-                assert(! Command_getEnv(c, "HELLO:WORLD"));
-                // Varargs
-                Command_vSetEnv(c, "PATH=%s; TERM=%s;", "/bin", "vterm");
-                assert(Str_isEqual(Command_getEnv(c, "PATH"), "/bin"));
-                assert(Str_isEqual(Command_getEnv(c, "TERM"), "vterm"));
+                assert(Str_isEqual(Command_getEnv(c, "PAT"), "Carroll"));
+                // Empty and NULL value
+                Command_setEnv(c, "PATH", "");
+                Command_setEnv(c, "SHELL", NULL);
+                assert(Str_isEqual(Command_getEnv(c, "PATH"), ""));
+                assert(Str_isEqual(Command_getEnv(c, "SHELL"), ""));
+                // Unknown variable should result in NULL
+                assert(Command_getEnv(c, "UKNOWNVARIABLE") == NULL);
                 Command_free(&c);
                 assert(!c);
         }
@@ -181,8 +181,26 @@ int main(void) {
                 assert(!c);
         }
         printf("=> Test5: OK\n\n");
-
-        printf("=> Test6: execute\n");
+        
+        printf("=> Test6: Append arguments\n");
+        {
+                Command_T c = Command_new("/bin/ls", NULL);
+                assert(c);
+                Command_appendArgument(c, "-l");
+                Command_appendArgument(c, "-t");
+                Command_appendArgument(c, "-r");
+                List_T l = Command_getCommand(c);
+                assert(Str_isEqual(l->head->e, "/bin/ls"));
+                assert(Str_isEqual(l->head->next->e, "-l"));
+                assert(Str_isEqual(l->head->next->next->e, "-t"));
+                assert(Str_isEqual(l->head->next->next->next->e, "-r"));
+                assert(l->head->next->next->next->next == NULL);
+                Command_free(&c);
+                assert(!c);
+        }
+        printf("=> Test6: OK\n\n");
+        
+        printf("=> Test7: execute invalid program\n");
         {
                 // Program producing error
                 Command_T c = Command_new("/bin/sh", "-c", "baluba;", NULL);
@@ -192,33 +210,66 @@ int main(void) {
                 onExec(Command_execute(c));
                 Command_free(&c);
                 assert(!c);
+        }
+        printf("=> Test7: OK\n\n");
 
-                // Correct program
-                c = Command_new("/bin/sh", "-c", "echo \"Please enter your name:\";read name;echo \"Hello $name\";", NULL);
+        printf("=> Test8: execute valid program\n");
+        {
+                Command_T c = Command_new("/bin/sh", "-c", "echo \"Please enter your name:\";read name;echo \"Hello $name\";", NULL);
                 assert(c);
                 onExec(Command_execute(c));
                 Command_free(&c);
                 assert(!c);
         }
-        printf("=> Test6: OK\n\n");
+        printf("=> Test8: OK\n\n");
 
-        printf("=> Test7: terminate and kill sub-process\n");
+        printf("=> Test9: terminate sub-process\n");
         {
-                // Test terminate
-                Command_T c = Command_new("/bin/sh", "-c", "sleep 30;", NULL);
+                Command_T c = Command_new("/bin/sh", "-c", "exec sleep 30;", NULL);
                 assert(c);
                 onTerminate(Command_execute(c));
                 Command_free(&c);
                 assert(!c);
+        }
+        printf("=> Test9: OK\n\n");
 
-                // Test kill
-                c = Command_new("/bin/sh", "-c", "trap 1 2 15; sleep 30; ", NULL);
+        printf("=> Test10: kill sub-process\n");
+        {
+                Command_T c = Command_new("/bin/sh", "-c", "trap 1 2 15; sleep 30; ", NULL);
                 assert(c);
                 onKill(Command_execute(c));
                 Command_free(&c);
                 assert(!c);
         }
-        printf("=> Test7: OK\n\n");
+        printf("=> Test10: OK\n\n");
+        
+        printf("=> Test11: environment in sub-process\n");
+        {
+                Command_T c = Command_new("/bin/sh", "-c", "echo $SULT", NULL);
+                assert(c);
+                // Set environment in sub-process only
+                Command_setEnv(c, "SULT", "Ylajali");
+                onEnv(Command_execute(c));
+                Command_free(&c);
+                assert(!c);
+        }
+        printf("=> Test11: OK\n\n");
+        
+#if ! defined(OPENBSD)
+        /* FIXME: MONIT-35: OpenBSD vfork() doesn't share memory, so the current implementation of Command_execute() cannot pass the execve() error to parent. Disable the unit test on OpenBSD for now. */
+        printf("=> Test12: on execute error\n");
+        {
+                // Try executing a directory should produce an error
+                Command_T c = Command_new("/tmp", NULL);
+                assert(c);
+                Process_T p = Command_execute(c);
+                assert(! p);
+                Command_free(&c);
+                printf("\tOK, got execute error -- %s\n", System_getLastError());
+                assert(!c);
+        }
+        printf("=> Test12: OK\n\n");
+#endif
 
         printf("============> Command Tests: OK\n\n");
 
