@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -91,12 +91,12 @@ void  daemonize() {
   /*
    * Become a session leader to lose our controlling terminal
    */
-  if((pid= fork ()) < 0) {
+  if((pid = fork ()) < 0) {
 
-    LogError("Cannot fork of a new process\n");  
+    LogError("Cannot fork of a new process\n");
     exit (1);
 
-  }  
+  }
   else if(pid != 0) {
 
     _exit(0);
@@ -105,12 +105,12 @@ void  daemonize() {
 
   setsid();
 
-  if((pid= fork ()) < 0) {
+  if((pid = fork ()) < 0) {
 
-    LogError("Cannot fork of a new process\n");  
+    LogError("Cannot fork of a new process\n");
     exit (1);
 
-  }  
+  }
   else if(pid != 0) {
 
     _exit(0);
@@ -135,7 +135,7 @@ void  daemonize() {
    */
   Util_redirectStdFds();
 
-} 
+}
 
 
 /**
@@ -147,25 +147,24 @@ int kill_daemon(int sig) {
 
   pid_t pid;
 
-  if ( (pid= exist_daemon()) > 0 ) {
+  if ( (pid = exist_daemon()) > 0 ) {
 
     if ( kill(pid, sig) < 0 ) {
 
-      LogError("%s: Cannot send signal to daemon process -- %s\n",
-        prog, STRERROR);
+      LogError("Cannot send signal to daemon process -- %s\n", STRERROR);
       return FALSE;
 
     }
 
   } else {
 
-    LogInfo("%s: No daemon process found\n", prog);
+    LogInfo("No daemon process found\n");
     return TRUE;
 
   }
 
   if(sig == SIGTERM) {
-	  
+
     fprintf(stdout, "%s daemon with pid [%d] killed\n", prog, (int)pid);
     fflush(stdout);
 
@@ -184,11 +183,11 @@ int exist_daemon() {
 
   pid_t pid;
 
-  errno= 0;
+  errno = 0;
 
-  if( (pid= Util_getPid(Run.pidfile)) )
+  if( (pid = Util_getPid(Run.pidfile)) )
     if( (getpgid(pid)) > -1 || (errno == EPERM) )
-      return( (int)pid );
+      return((int)pid);
 
   return(FALSE);
 
