@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 /**
@@ -75,7 +75,7 @@ char *device_mountpoint_sysdep(Info_T inf, char *blockdev) {
   ASSERT(blockdev);
 
   if ((mntfd = setmntent("/etc/mtab", "r")) == NULL) {
-    LogError("%s: Cannot open /etc/mtab file\n", prog);
+    LogError("Cannot open /etc/mtab file\n");
     return NULL;
   }
   while ((mnt = getmntent(mntfd)) != NULL) {
@@ -106,7 +106,7 @@ int filesystem_usage_sysdep(Info_T inf) {
   ASSERT(inf);
 
   if (statvfs(inf->priv.filesystem.mntpath, &usage) != 0) {
-    LogError("%s: Error getting usage statistics for filesystem '%s' -- %s\n", prog, inf->priv.filesystem.mntpath, STRERROR);
+    LogError("Error getting usage statistics for filesystem '%s' -- %s\n", inf->priv.filesystem.mntpath, STRERROR);
     return FALSE;
   }
   inf->priv.filesystem.f_bsize =           usage.f_bsize;
