@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
@@ -92,20 +92,20 @@ void file_init() {
     } else {
       snprintf(pidfile, STRLEN, "%s/.%s", Run.Env.home, MYPIDFILE);
     }
-    Run.pidfile= Str_dup(pidfile);
+    Run.pidfile = Str_dup(pidfile);
   }
 
   /* Set the location of monit's id file */
   if(Run.idfile == NULL) {
     snprintf(buf, STRLEN, "%s/.%s", Run.Env.home, MYIDFILE);
-    Run.idfile= Str_dup(buf);
+    Run.idfile = Str_dup(buf);
   }
   Util_monitId(Run.idfile);
 
   /* Set the location of monit's state file */
   if(Run.statefile == NULL) {
     snprintf(buf, STRLEN, "%s/.%s", Run.Env.home, MYSTATEFILE);
-    Run.statefile= Str_dup(buf);
+    Run.statefile = Str_dup(buf);
   }
 
 }
@@ -120,7 +120,7 @@ void file_finalize() {
   if (! file_exist(Run.idfile)) {
     FILE *f =  fopen(Run.idfile,"w");
     if (! f) {
-      LogError("%s: Error opening Monit id file '%s' for writing -- %s\n", prog, Run.idfile, STRERROR);
+      LogError("Error opening Monit id file '%s' for writing -- %s\n", Run.idfile, STRERROR);
     } else {
       fprintf(f, "%s\n", Run.id);
       fclose(f);
@@ -145,12 +145,12 @@ time_t file_getTimestamp(char *object, mode_t type) {
   if(! stat(object, &buf)) {
     if(((type == S_IFREG) && S_ISREG(buf.st_mode)) ||
        ((type == S_IFDIR) && S_ISDIR(buf.st_mode)) ||
-       ((type == (S_IFREG|S_IFDIR)) && (S_ISREG(buf.st_mode) ||
-					S_ISDIR(buf.st_mode)))
+       ((type == S_IFSOCK) && S_ISSOCK(buf.st_mode)) ||
+       ((type == (S_IFREG|S_IFDIR)) && (S_ISREG(buf.st_mode) || S_ISDIR(buf.st_mode)))
        ) {
       return MAX(buf.st_mtime, buf.st_ctime);
     } else {
-      LogError("%s: Invalid object type - %s\n", prog, object);
+      LogError("Invalid object type - %s\n", object);
     }
   }
 
@@ -168,7 +168,7 @@ time_t file_getTimestamp(char *object, mode_t type) {
  */
 char *file_findControlFile() {
 
-  char *rcfile= CALLOC(sizeof(char), STRLEN + 1);
+  char *rcfile = CALLOC(sizeof(char), STRLEN + 1);
 
   snprintf(rcfile, STRLEN, "%s/.%s", Run.Env.home, MONITRC);
   if(file_exist(rcfile)) {
@@ -190,8 +190,7 @@ char *file_findControlFile() {
     snprintf(rcfile, STRLEN, "%s/%s", Run.Env.cwd, MONITRC);
     return rcfile;
   }
-  LogError("%s: Cannot find the control file at ~/.%s, /etc/%s, %s/%s, /usr/local/etc/%s or at ./%s \n",
-      prog, MONITRC, MONITRC, SYSCONFDIR, MONITRC, MONITRC, MONITRC);
+  LogError("Cannot find the control file at ~/.%s, /etc/%s, %s/%s, /usr/local/etc/%s or at ./%s \n", MONITRC, MONITRC, SYSCONFDIR, MONITRC, MONITRC, MONITRC);
   exit(1);
 
 }
@@ -199,20 +198,20 @@ char *file_findControlFile() {
 
 /**
  * Create a program's pidfile - Such a file is created when in daemon
- * mode. The file is created with mask = MYPIDMASK (usually 644).  
+ * mode. The file is created with mask = MYPIDMASK (usually 644).
  * @param pidfile The name of the pidfile to create
- * @return TRUE if the file was created, otherwise FALSE. 
+ * @return TRUE if the file was created, otherwise FALSE.
  */
 int file_createPidFile(char *pidfile) {
 
-  FILE *F= NULL;
+  FILE *F = NULL;
 
   ASSERT(pidfile);
 
   umask(MYPIDMASK);
   unlink(pidfile);
-  if ((F= fopen(pidfile,"w")) == (FILE *)NULL) {
-    LogError("%s: Error opening pidfile '%s' for writing -- %s\n", prog, pidfile, STRERROR);
+  if ((F = fopen(pidfile,"w")) == (FILE *)NULL) {
+    LogError("Error opening pidfile '%s' for writing -- %s\n", pidfile, STRERROR);
     return(FALSE);
   }
   fprintf(F, "%d\n", (int)getpid());
@@ -247,10 +246,10 @@ int file_isFile(char *file) {
  */
 int file_isDirectory(char *dir) {
 
-	struct stat buf;
+        struct stat buf;
 
   ASSERT(dir);
-	
+
   return (stat(dir, &buf) == 0 && S_ISDIR(buf.st_mode));
 
 }
@@ -299,55 +298,55 @@ int file_exist(char *file) {
  */
 int file_checkStat(char *filename, char *description, int permmask) {
   struct stat buf;
-  errno= 0;
+  errno = 0;
 
   ASSERT(filename);
   ASSERT(description);
 
   if(stat(filename, &buf) < 0) {
-    LogError("%s: Cannot stat the %s '%s' -- %s\n", prog, description, filename, STRERROR);
+    LogError("Cannot stat the %s '%s' -- %s\n", description, filename, STRERROR);
     return FALSE;
   }
   if(!S_ISREG(buf.st_mode)) {
-    LogError("%s: The %s '%s' is not a regular file.\n", prog, description,  filename);
+    LogError("The %s '%s' is not a regular file.\n", description,  filename);
     return FALSE;
   }
   if(buf.st_uid != geteuid())  {
-    LogError("%s: The %s '%s' must be owned by you.\n", prog, description, filename);
+    LogError("The %s '%s' must be owned by you.\n", description, filename);
     return FALSE;
   }
   if((buf.st_mode & 0777 ) & ~permmask) {
-    /* 
-       Explanation: 
+    /*
+       Explanation:
 
            buf.st_mode & 0777 ->  We just want to check the
-                                  permissions not the file type... 
+                                  permissions not the file type...
                                   we did it already!
            () & ~permmask ->      We check if there are any other
-                                  permissions set than in permmask 
+                                  permissions set than in permmask
     */
-    LogError("%s: The %s '%s' must have permissions no more than -%c%c%c%c%c%c%c%c%c (0%o); right now permissions are -%c%c%c%c%c%c%c%c%c (0%o).\n", 
-	prog, description, filename, 
-	permmask&S_IRUSR?'r':'-',
-	permmask&S_IWUSR?'w':'-',
-	permmask&S_IXUSR?'x':'-',
-	permmask&S_IRGRP?'r':'-',
-	permmask&S_IWGRP?'w':'-',
-	permmask&S_IXGRP?'x':'-',
-	permmask&S_IROTH?'r':'-',
-	permmask&S_IWOTH?'w':'-',
-	permmask&S_IXOTH?'x':'-',
-	permmask&0777,
-	buf.st_mode&S_IRUSR?'r':'-',
-	buf.st_mode&S_IWUSR?'w':'-',
-	buf.st_mode&S_IXUSR?'x':'-',
-	buf.st_mode&S_IRGRP?'r':'-',
-	buf.st_mode&S_IWGRP?'w':'-',
-	buf.st_mode&S_IXGRP?'x':'-',
-	buf.st_mode&S_IROTH?'r':'-',
-	buf.st_mode&S_IWOTH?'w':'-',
-	buf.st_mode&S_IXOTH?'x':'-',
-	buf.st_mode& 0777);
+    LogError("The %s '%s' must have permissions no more than -%c%c%c%c%c%c%c%c%c (0%o); right now permissions are -%c%c%c%c%c%c%c%c%c (0%o).\n",
+        description, filename,
+        permmask&S_IRUSR?'r':'-',
+        permmask&S_IWUSR?'w':'-',
+        permmask&S_IXUSR?'x':'-',
+        permmask&S_IRGRP?'r':'-',
+        permmask&S_IWGRP?'w':'-',
+        permmask&S_IXGRP?'x':'-',
+        permmask&S_IROTH?'r':'-',
+        permmask&S_IWOTH?'w':'-',
+        permmask&S_IXOTH?'x':'-',
+        permmask&0777,
+        buf.st_mode&S_IRUSR?'r':'-',
+        buf.st_mode&S_IWUSR?'w':'-',
+        buf.st_mode&S_IXUSR?'x':'-',
+        buf.st_mode&S_IRGRP?'r':'-',
+        buf.st_mode&S_IWGRP?'w':'-',
+        buf.st_mode&S_IXGRP?'x':'-',
+        buf.st_mode&S_IROTH?'r':'-',
+        buf.st_mode&S_IWOTH?'w':'-',
+        buf.st_mode&S_IXOTH?'x':'-',
+        buf.st_mode& 0777);
     return FALSE;
   }
 
@@ -373,17 +372,15 @@ int file_checkQueueDirectory(char *path, mode_t mode) {
       rv = mkdir(path, mode);
       umask(mask);
       if(rv) {
-        LogError("%s: cannot create the event queue directory %s -- %s\n",
-          prog, path, STRERROR);
+        LogError("Cannot create the event queue directory %s -- %s\n", path, STRERROR);
         return FALSE;
       }
     } else {
-      LogError("%s: cannot read the event queue directory %s -- %s\n",
-        prog, path, STRERROR);
+      LogError("Cannot read the event queue directory %s -- %s\n", path, STRERROR);
       return FALSE;
     }
   } else if(! S_ISDIR(st.st_mode)) {
-    LogError("%s: event queue: the %s is not the directory\n", prog, path);
+    LogError("Event queue: the %s is not directory\n", path);
     return FALSE;
   }
   return TRUE;
@@ -405,14 +402,14 @@ int file_checkQueueLimit(char *path, int limit) {
     return TRUE;
 
   if(! (dir = opendir(path)) ) {
-    LogError("%s: cannot open the event queue directory %s -- %s\n", prog, path, STRERROR);
+    LogError("Cannot open the event queue directory %s -- %s\n", path, STRERROR);
     return FALSE;
   }
   while( (de = readdir(dir)) ) {
     struct stat st;
 
     if(!stat(de->d_name, &st) && S_ISREG(st.st_mode) && ++used > limit) {
-      LogError("%s: event queue full\n", prog);
+      LogError("Event queue is full\n");
       closedir(dir);
       return FALSE;
     }
@@ -437,9 +434,9 @@ int file_writeQueue(FILE *file, void *data, size_t size) {
   /* write size */
   if((rv = fwrite(&size, 1, sizeof(size_t), file)) != sizeof(size_t)) {
     if (feof(file) || ferror(file))
-      LogError("%s: queued event file: unable to write event size -- %s\n", prog, feof(file) ? "end of file" : "stream error");
+      LogError("Queued event file: unable to write event size -- %s\n", feof(file) ? "end of file" : "stream error");
     else
-      LogError("%s: queued event file: unable to write event size -- read returned %d bytes\n", prog, rv);
+      LogError("Queued event file: unable to write event size -- read returned %d bytes\n", rv);
     return FALSE;
   }
 
@@ -447,9 +444,9 @@ int file_writeQueue(FILE *file, void *data, size_t size) {
   if(size > 0) {
     if((rv = fwrite(data, 1, size, file)) != size) {
       if (feof(file) || ferror(file))
-        LogError("%s: queued event file: unable to write event size -- %s\n", prog, feof(file) ? "end of file" : "stream error");
+        LogError("Queued event file: unable to write event size -- %s\n", feof(file) ? "end of file" : "stream error");
       else
-        LogError("%s: queued event file: unable to write event size -- read returned %d bytes\n", prog, rv);
+        LogError("Queued event file: unable to write event size -- read returned %d bytes\n", rv);
       return FALSE;
     }
   }
@@ -474,9 +471,9 @@ void *file_readQueue(FILE *file, size_t *size) {
   /* read size */
   if((rv = fread(size, 1, sizeof(size_t), file)) != sizeof(size_t)) {
     if (feof(file) || ferror(file))
-      LogError("%s: queued event file: unable to read event size -- %s\n", prog, feof(file) ? "end of file" : "stream error");
+      LogError("Queued event file: unable to read event size -- %s\n", feof(file) ? "end of file" : "stream error");
     else
-      LogError("%s: queued event file: unable to read event size -- read returned %d bytes\n", prog, rv);
+      LogError("Queued event file: unable to read event size -- read returned %d bytes\n", rv);
     return NULL;
   }
 
@@ -486,9 +483,9 @@ void *file_readQueue(FILE *file, size_t *size) {
     if((rv = fread(data, 1, *size, file)) != *size) {
       FREE(data);
       if (feof(file) || ferror(file))
-        LogError("%s: queued event file: unable to read event data -- %s\n", prog, feof(file) ? "end of file" : "stream error");
+        LogError("Queued event file: unable to read event data -- %s\n", feof(file) ? "end of file" : "stream error");
       else
-        LogError("%s: queued event file: unable to read event data -- read returned %d bytes\n", prog, rv);
+        LogError("Queued event file: unable to read event data -- read returned %d bytes\n", rv);
       return NULL;
     }
   }
