@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
@@ -145,7 +145,7 @@ void gccmd(command_t *c) {
 
         ASSERT(c&&*c);
 
-        for(i= 0; (*c)->arg[i]; i++)
+        for(i = 0; (*c)->arg[i]; i++)
                 FREE((*c)->arg[i]);
         FREE(*c);
 
@@ -159,7 +159,7 @@ void gc_event(Event_T *e) {
         if((*e)->next)
                 gc_event(&(*e)->next);
 
-        (*e)->action= NULL;
+        (*e)->action = NULL;
         FREE((*e)->source);
         FREE((*e)->message);
         FREE(*e);
@@ -191,6 +191,9 @@ static void _gc_service(Service_T *s) {
                         Process_free(&(*s)->program->P);
                 if ((*s)->program->C)
                         Command_free(&(*s)->program->C);
+                if ((*s)->program->args)
+                        gccmd(&(*s)->program->args);
+                FREE((*s)->program);
         }
 
         if((*s)->portlist)
@@ -241,6 +244,9 @@ static void _gc_service(Service_T *s) {
         if((*s)->uid)
                 _gcuid(&(*s)->uid);
 
+        if((*s)->euid)
+                _gcuid(&(*s)->euid);
+
         if((*s)->gid)
                 _gcgid(&(*s)->gid);
 
@@ -292,7 +298,7 @@ static void _gc_service(Service_T *s) {
         FREE((*s)->name);
         FREE((*s)->path);
 
-        (*s)->next= NULL;
+        (*s)->next = NULL;
 
         FREE(*s);
 
