@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
@@ -90,6 +90,9 @@
 #include "engine.h"
 #include "socket.h"
 
+// libmonit
+#include "system/Net.h"
+
 
 /**
  *  A naive http 1.0 server. The server delegates handling of a HTTP
@@ -107,18 +110,18 @@
  *    accepted. Hosts allowed to connect to this server should be
  *    added to the access control list by calling add_host_allow().
  *
- *  @file 
+ *  @file
  */
 
 
 /* ------------------------------------------------------------- Definitions */
 
 
-static int myServerSocket= 0;
-static HostsAllow hostlist= NULL;
-static volatile int stopped= FALSE;
-ssl_server_connection *mySSLServerConnection= NULL;
-static pthread_mutex_t hostlist_mutex= PTHREAD_MUTEX_INITIALIZER;
+static int myServerSocket = 0;
+static HostsAllow hostlist = NULL;
+static volatile int stopped = FALSE;
+ssl_server_connection *mySSLServerConnection = NULL;
+static pthread_mutex_t hostlist_mutex = PTHREAD_MUTEX_INITIALIZER;
 struct ulong_net {
   unsigned long network;
   unsigned long mask;
@@ -142,19 +145,19 @@ static int  parse_network(char *, struct ulong_net *);
 /**
  * Start the HTTPD server
  * @param port The Port number to start the server at
- * @param backlog The maximum length of the incomming connection queue 
+ * @param backlog The maximum length of the incomming connection queue
  * @param bindAddr the local address the server will bind to
  */
 void start_httpd(int port, int backlog, char *bindAddr) {
 
-  Socket_T S= NULL;
+  Socket_T S = NULL;
 
-  stopped= Run.stopped;
+  stopped = Run.stopped;
 
-  if((myServerSocket= create_server_socket(port, backlog, bindAddr)) < 0) {
+  if((myServerSocket = create_server_socket(port, backlog, bindAddr)) < 0) {
 
     LogError("http server: Could not create a server socket at port %d -- %s\n",
-	port, STRERROR);
+        port, STRERROR);
 
     LogError("monit HTTP server not available\n");
 
@@ -171,35 +174,34 @@ void start_httpd(int port, int backlog, char *bindAddr) {
 
     if(Run.httpdssl) {
 
-      mySSLServerConnection= init_ssl_server( Run.httpsslpem,
-					      Run.httpsslclientpem);
+      mySSLServerConnection = init_ssl_server( Run.httpsslpem, Run.httpsslclientpem);
 
       if(mySSLServerConnection == NULL) {
-	
-	LogError("http server: Could not initialize SSL engine\n");
-	
-	LogError("monit HTTP server not available\n");
-	
-	return;
+
+        LogError("http server: Could not initialize SSL engine\n");
+
+        LogError("monit HTTP server not available\n");
+
+        return;
       }
 
 #ifdef HAVE_OPENSSL
-      mySSLServerConnection->server_socket= myServerSocket;
+      mySSLServerConnection->server_socket = myServerSocket;
 #endif
     }
 
     while(! stopped) {
 
-      if(!(S= socket_producer(myServerSocket, port, mySSLServerConnection))) {
-	continue;
+      if(!(S = socket_producer(myServerSocket, port, mySSLServerConnection))) {
+        continue;
       }
 
       http_processor(S);
 
     }
 
-    delete_ssl_server_socket(mySSLServerConnection);  
-    close_socket(myServerSocket);
+    delete_ssl_server_socket(mySSLServerConnection);
+    Net_close(myServerSocket);
 
   }
 
@@ -207,11 +209,11 @@ void start_httpd(int port, int backlog, char *bindAddr) {
 
 
 /**
- * Stop the HTTPD server. 
+ * Stop the HTTPD server.
  */
 void stop_httpd() {
 
-  stopped= TRUE;
+  stopped = TRUE;
 
 }
 
@@ -244,25 +246,25 @@ int add_host_allow(char *name) {
        HostsAllow h;
        struct sockaddr_in *sin = (struct sockaddr_in *)_res->ai_addr;
 
-       NEW(h);      
+       NEW(h);
        memcpy(&h->network, &sin->sin_addr, 4);
-       h->mask=    0xffffffff;
+       h->mask =    0xffffffff;
        LOCK(hostlist_mutex)
        if(hostlist) {
          HostsAllow p, n;
-         for(n= p= hostlist; p; n= p, p= p->next) {
+         for(n = p = hostlist; p; n = p, p = p->next) {
            if((p->network == h->network) && ((p->mask == h->mask))) {
-             DEBUG("%s: Debug: Skipping redundant host '%s'\n", prog, name); 
+             DEBUG("Skipping redundant host '%s'\n", name);
              destroy_host_allow(h);
              goto done;
            }
          }
-         DEBUG("%s: Debug: Adding host allow '%s'\n", prog, name); 
-         n->next= h;
+         DEBUG("Adding host allow '%s'\n", name);
+         n->next = h;
        } else {
-         DEBUG("%s: Debug: Adding host allow '%s'\n", prog, name);
+         DEBUG("Adding host allow '%s'\n", name);
 
-         hostlist= h;
+         hostlist = h;
        }
        done:
        END_LOCK;
@@ -307,31 +309,21 @@ int add_net_allow(char *s_network) {
 
     HostsAllow p, n;
 
-    for(n= p= hostlist; p; n= p, p= p->next) {
+    for(n = p = hostlist; p; n = p, p = p->next) {
 
       if((p->network == net.network) && ((p->mask == net.mask))) {
-	
-        DEBUG("%s: Debug: Skipping redundant net '%s'.\n",
-              prog, s_network); 
+        DEBUG("Skipping redundant net '%s'\n", s_network);
         destroy_host_allow(h);
         goto done;
-	
       }
 
     }
-
-    DEBUG("%s: Debug: Adding net allow '%s'.\n",
-          prog, s_network); 
-
-    n->next= h;
+    DEBUG("Adding net allow '%s'\n", s_network);
+    n->next = h;
 
   } else {
-
-    DEBUG("%s: Debug: Adding net allow '%s'.\n",
-          prog, s_network); 
-
-    hostlist= h;
-
+    DEBUG("Adding net allow '%s'\n", s_network);
+    hostlist = h;
   }
 
   done:
@@ -350,7 +342,7 @@ int has_hosts_allow() {
   int rv;
 
   LOCK(hostlist_mutex)
-      rv= (hostlist != NULL);
+      rv = (hostlist != NULL);
   END_LOCK;
 
   return rv;
@@ -358,7 +350,7 @@ int has_hosts_allow() {
 }
 
 
-/** 
+/**
  * Free the host allow list
  */
 void destroy_hosts_allow() {
@@ -366,8 +358,8 @@ void destroy_hosts_allow() {
   if(has_hosts_allow()) {
 
     LOCK(hostlist_mutex)
-	destroy_host_allow(hostlist);
-        hostlist= NULL;
+        destroy_host_allow(hostlist);
+        hostlist = NULL;
     END_LOCK;
 
   }
@@ -425,8 +417,7 @@ static int authenticate(const struct in_addr addr) {
 
   }
 
-  LogError("%s: Denied connection from non-authorized client [%s]\n", prog,
-      inet_ntoa(addr));
+  LogError("Denied connection from non-authorized client [%s]\n", inet_ntoa(addr));
 
   return FALSE;
 
@@ -437,18 +428,18 @@ static int authenticate(const struct in_addr addr) {
  * Returns TRUE if host is allowed to connect to
  * this server
  */
-static int is_host_allow(const struct in_addr addr) { 
+static int is_host_allow(const struct in_addr addr) {
 
   HostsAllow p;
-  int rv= FALSE;
+  int rv = FALSE;
 
   LOCK(hostlist_mutex)
 
-  for(p= hostlist; p; p= p->next) {
+  for(p = hostlist; p; p = p->next) {
 
     if((p->network & p->mask) == (addr.s_addr & p->mask)) {
 
-      rv= TRUE;
+      rv = TRUE;
       break;
 
     }
@@ -486,7 +477,7 @@ static int parse_network(char *s_network, struct ulong_net *net) {
   ASSERT(s_network);
   ASSERT(net);
 
-  temp= copy= Str_dup(s_network);
+  temp = copy = Str_dup(s_network);
 
   /* decide if we have xxx.xxx.xxx.xxx/yyy or
                        xxx.xxx.xxx.xxx/yyy.yyy.yyy.yyy */
@@ -505,7 +496,7 @@ static int parse_network(char *s_network, struct ulong_net *net) {
       }
 
       *temp=0;
-      longmask= *(temp+1)?temp+1:NULL;
+      longmask = *(temp+1)?temp+1:NULL;
       count=0;
       slashcount=1;
       dotcount=0;
@@ -532,7 +523,7 @@ static int parse_network(char *s_network, struct ulong_net *net) {
 
     /* We have just host portion */
 
-    shortmask= 32;
+    shortmask = 32;
 
   } else if ((dotcount==0) && (count > 1) && (count < 4)) {
 
@@ -576,17 +567,17 @@ static int parse_network(char *s_network, struct ulong_net *net) {
 
     } else {
 
-      net->mask= (1<<shortmask)-1;
-      net->mask= htonl(net->mask<<(32-shortmask));
+      net->mask = (1<<shortmask)-1;
+      net->mask = htonl(net->mask<<(32-shortmask));
 
     }
 
-  } else { 	 
-  	 
-    /* Parse long netmasks */ 	 
-    if (inet_aton(longmask, &inp) == 0) { 	 
+  } else {
 
-      goto done; 	 
+    /* Parse long netmasks */
+    if (inet_aton(longmask, &inp) == 0) {
+
+      goto done;
 
     }
 
@@ -618,11 +609,11 @@ static Socket_T socket_producer(int server, int port, void *sslserver) {
 
   int client;
   struct sockaddr_in in;
-  socklen_t len= sizeof(struct sockaddr_in);
+  socklen_t len = sizeof(struct sockaddr_in);
 
   if(can_read(server, 1)) {
 
-    if( (client= accept(server, (struct sockaddr*)&in, &len)) < 0) {
+    if( (client = accept(server, (struct sockaddr*)&in, &len)) < 0) {
 
       if(stopped) {
         LogError("http server: service stopped\n");
@@ -643,7 +634,7 @@ static Socket_T socket_producer(int server, int port, void *sslserver) {
 
   }
 
-  if(set_noblock(client) < 0) {
+  if (Net_setNonBlocking(client) < 0) {
     goto error;
   }
 
@@ -659,7 +650,7 @@ static Socket_T socket_producer(int server, int port, void *sslserver) {
   return socket_create_a(client, inet_ntoa(in.sin_addr), port, sslserver);
 
   error:
-  close_socket(client);
+  Net_abort(client);
   return NULL;
 
 }
@@ -669,11 +660,11 @@ static Socket_T socket_producer(int server, int port, void *sslserver) {
 
 
 /**
- * Free a (linked list of) host_allow ojbect(s). 
+ * Free a (linked list of) host_allow ojbect(s).
  */
 static void destroy_host_allow(HostsAllow p) {
 
-  HostsAllow a= p; 
+  HostsAllow a = p;
 
   if(a->next) {
     destroy_host_allow(a->next);
