@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
@@ -94,14 +94,14 @@
 /* ------------------------------------------------------------- Definitions */
 
 
-static FILE *LOG= NULL;
+static FILE *LOG = NULL;
 static pthread_mutex_t log_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 
 static struct mylogpriority {
   int  priority;
   char *description;
-} logPriority[]= {
+} logPriority[] = {
   {LOG_EMERG,   "emergency"},
     {LOG_ALERT,   "alert"},
     {LOG_CRIT,    "critical"},
@@ -207,7 +207,9 @@ void vLogAbortHandler(const char *s, va_list ap) {
         va_copy(ap_copy, ap);
         log_log(LOG_CRIT, s, ap);
         va_end(ap_copy);
-        abort();
+        if (Run.debug)
+                abort();
+        exit(1);
 }
 
 
@@ -291,13 +293,13 @@ void LogInfo(const char *s, ...) {
  * @param s A formated (printf-style) string to log
  */
 void LogDebug(const char *s, ...) {
-  va_list ap;
-
-  ASSERT(s);
-
-  va_start(ap, s);
-  log_log(LOG_DEBUG, s, ap);
-  va_end(ap);
+        ASSERT(s);
+        if (Run.debug) {
+                va_list ap;
+                va_start(ap, s);
+                log_log(LOG_DEBUG, s, ap);
+                va_end(ap);
+        }
 }
 
 
@@ -307,14 +309,14 @@ void LogDebug(const char *s, ...) {
 void log_close() {
 
   if (Run.use_syslog) {
-    closelog(); 
+    closelog();
   }
 
   if (LOG  && (0 != fclose(LOG))) {
-    LogError("%s: Error closing the log file -- %s\n",	prog, STRERROR);
+    LogError("Error closing the log file -- %s\n", STRERROR);
   }
 
-  LOG= NULL;
+  LOG = NULL;
 
 }
 
@@ -340,11 +342,11 @@ void vsyslog (int facility_priority, const char *format, va_list arglist) {
 static int open_log() {
 
   if (Run.use_syslog) {
-    openlog(prog, LOG_PID, Run.facility); 
+    openlog(prog, LOG_PID, Run.facility);
   } else {
     umask(LOGMASK);
-    if ((LOG= fopen(Run.logfile,"a+")) == (FILE *)NULL) {
-      LogError("%s: Error opening the log file '%s' for writing -- %s\n", prog, Run.logfile, STRERROR);
+    if ((LOG = fopen(Run.logfile,"a+")) == (FILE *)NULL) {
+      LogError("Error opening the log file '%s' for writing -- %s\n", Run.logfile, STRERROR);
       return(FALSE);
     }
     /* Set logger in unbuffered mode */
@@ -380,7 +382,7 @@ static char *timefmt(char *t, int size) {
  */
 static const char *logPriorityDescription(int p) {
 
-  struct mylogpriority *lp= logPriority;
+  struct mylogpriority *lp = logPriority;
 
   while ((*lp).description)
   {
@@ -397,7 +399,7 @@ static const char *logPriorityDescription(int p) {
 
 
 /**
- * Log a message to monits logfile or syslog. 
+ * Log a message to monits logfile or syslog.
  * @param priority A message priority
  * @param s A formated (printf-style) string to log
  */
