@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -79,7 +79,9 @@
 
 // libmonit
 #include "Bootstrap.h"
+#include "io/Dir.h"
 #include "io/File.h"
+#include "exceptions/AssertException.h"
 
 
 /**
@@ -161,7 +163,7 @@ int main(int argc, char **argv) {
         init_env();
         handle_options(argc, argv);
         do_init();
-        do_action(argv); 
+        do_action(argv);
         do_exit();
         return 0;
 }
@@ -243,7 +245,7 @@ static void do_init() {
          */
         status = pthread_mutex_init(&Run.mutex, NULL);
         if (status != 0) {
-                LogError("%s: Cannot initialize mutex -- %s\n", prog, strerror(status));
+                LogError("Cannot initialize mutex -- %s\n", strerror(status));
                 exit(1);
         }
 
@@ -252,17 +254,17 @@ static void do_init() {
          */
         status = pthread_mutex_init(&heartbeatMutex, NULL);
         if (status != 0) {
-                LogError("%s: Cannot initialize heartbeat mutex -- %s\n", prog, strerror(status));
+                LogError("Cannot initialize heartbeat mutex -- %s\n", strerror(status));
                 exit(1);
         }
         status = pthread_cond_init(&heartbeatCond, NULL);
         if (status != 0) {
-                LogError("%s: Cannot initialize heartbeat condition -- %s\n", prog, strerror(status));
+                LogError("Cannot initialize heartbeat condition -- %s\n", strerror(status));
                 exit(1);
         }
 
-        /* 
-         * Get the position of the control file 
+        /*
+         * Get the position of the control file
          */
         if (! Run.controlfile)
                 Run.controlfile = file_findControlFile();
@@ -280,37 +282,26 @@ static void do_init() {
                 exit(1);
 
         /*
-         * Stop and report success if we are just validating the Control
-         * file syntax. The previous parse statement exits the program with
-         * an error message if a syntax error is present in the control
-         * file.
-         */
-        if (Run.testing) {
-                LogInfo("Control file syntax OK\n");
-                exit(0);
-        }
-
-        /*
-         * Initialize the log system 
+         * Initialize the log system
          */
         if (! log_init())
                 exit(1);
 
-        /* 
-         * Did we find any service ?  
+        /*
+         * Did we find any service ?
          */
         if (! servicelist) {
-                LogError("%s: No services has been specified\n", prog);
+                LogError("No services has been specified\n");
                 exit(0);
         }
 
-        /* 
-         * Initialize Runtime file variables 
+        /*
+         * Initialize Runtime file variables
          */
         file_init();
 
-        /* 
-         * Should we print debug information ? 
+        /*
+         * Should we print debug information ?
          */
         if (Run.debug) {
                 Util_printRunList();
@@ -337,16 +328,16 @@ static void do_reinit() {
         /* Wait non-blocking for any children that has exited. Since we
          reinitialize any information about children we have setup to wait
          for will be lost. This may create zombie processes until Monit
-         itself exit. However, Monit will wait on all children that has exited 
-         before it ifself exit. TODO: Later refactored versions will use a 
+         itself exit. However, Monit will wait on all children that has exited
+         before it ifself exit. TODO: Later refactored versions will use a
          globale process table which a sigchld handler can check */
         waitforchildren();
 
         if(Run.mmonits && heartbeatRunning) {
                 if ((status = pthread_cond_signal(&heartbeatCond)) != 0)
-                        LogError("%s: Failed to signal the heartbeat thread -- %s\n", prog, strerror(status));
+                        LogError("Failed to signal the heartbeat thread -- %s\n", strerror(status));
                 if ((status = pthread_join(heartbeatThread, NULL)) != 0)
-                        LogError("%s: Failed to stop the heartbeat thread -- %s\n", prog, strerror(status));
+                        LogError("Failed to stop the heartbeat thread -- %s\n", strerror(status));
                 heartbeatRunning = FALSE;
         }
 
@@ -377,7 +368,7 @@ static void do_reinit() {
 
         /* Did we find any services ?  */
         if (! servicelist) {
-                LogError("%s: No services has been specified\n", prog);
+                LogError("No services has been specified\n");
                 exit(0);
         }
 
@@ -402,7 +393,7 @@ static void do_reinit() {
         Event_post(Run.system, Event_Instance, STATE_CHANGED, Run.system->action_MONIT_RELOAD, "Monit reloaded");
 
         if(Run.mmonits && ((status = pthread_create(&heartbeatThread, NULL, heartbeat, NULL)) != 0))
-                LogError("%s: Failed to create the heartbeat thread -- %s\n", prog, strerror(status));
+                LogError("Failed to create the heartbeat thread -- %s\n", strerror(status));
         else
                 heartbeatRunning = TRUE;
 }
@@ -457,11 +448,11 @@ static void do_action(char **args) {
                         if (errors)
                                 exit(1);
                 } else {
-                        LogError("%s: please specify the configured service name or 'all' after %s\n", prog, action);
+                        LogError("Please specify a service name or 'all' after %s\n", action);
                         exit(1);
                 }
         } else if (IS(action, "reload")) {
-                LogInfo("Reinitializing monit daemon\n", prog);
+                LogInfo("Reinitializing %s daemon\n", prog);
                 kill_daemon(SIGHUP);
         } else if (IS(action, "status")) {
                 status(LEVEL_NAME_FULL);
@@ -479,7 +470,7 @@ static void do_action(char **args) {
                 if (! validate())
                         exit(1);
         } else {
-                LogError("%s: invalid argument -- %s  (-h will show valid arguments)\n", prog, action);
+                LogError("Invalid argument -- %s  (-h will show valid arguments)\n", action);
                 exit(1);
         }
 }
@@ -500,9 +491,9 @@ static void do_exit() {
 
                 if(Run.mmonits && heartbeatRunning) {
                         if ((status = pthread_cond_signal(&heartbeatCond)) != 0)
-                                LogError("%s: Failed to signal the heartbeat thread -- %s\n", prog, strerror(status));
+                                LogError("Failed to signal the heartbeat thread -- %s\n", strerror(status));
                         if ((status = pthread_join(heartbeatThread, NULL)) != 0)
-                                LogError("%s: Failed to stop the heartbeat thread -- %s\n", prog, strerror(status));
+                                LogError("Failed to stop the heartbeat thread -- %s\n", strerror(status));
                         heartbeatRunning = FALSE;
                 }
 
@@ -538,7 +529,7 @@ static void do_default() {
                         LogInfo("Monit start delay set -- pause for %ds\n", Run.startdelay);
 
                 if (Run.init != TRUE)
-                        daemonize(); 
+                        daemonize();
                 else if (! Run.debug)
                         Util_redirectStdFds();
 
@@ -573,7 +564,7 @@ static void do_default() {
                 Event_post(Run.system, Event_Instance, STATE_CHANGED, Run.system->action_MONIT_START, "Monit started");
 
                 if(Run.mmonits && ((status = pthread_create(&heartbeatThread, NULL, heartbeat, NULL)) != 0))
-                        LogError("%s: Failed to create the heartbeat thread -- %s\n", prog, strerror(status));
+                        LogError("Failed to create the heartbeat thread -- %s\n", strerror(status));
                 else
                         heartbeatRunning = TRUE;
 
@@ -609,96 +600,158 @@ static void handle_options(int argc, char **argv) {
         int opt;
         opterr = 0;
         Run.mygroup = NULL;
-
-        while ((opt = getopt(argc,argv,"c:d:g:l:p:s:iItvVhH")) != -1) {
-
-                switch(opt) {
-
+        const char *shortopts = "c:d:g:l:p:s:HIirtvVh";
+#ifdef HAVE_GETOPT_LONG
+        struct option longopts[] = {
+                {"conf",        required_argument,      NULL,   'c'},
+                {"daemon",      required_argument,      NULL,   'd'},
+                {"group",       required_argument,      NULL,   'g'},
+                {"logfile",     required_argument,      NULL,   'l'},
+                {"pidfile",     required_argument,      NULL,   'p'},
+                {"statefile",   required_argument,      NULL,   's'},
+                {"hash",        optional_argument,      NULL,   'H'},
+                {"interactive", no_argument,            NULL,   'I'},
+                {"id",          no_argument,            NULL,   'i'},
+                {"resetid",     no_argument,            NULL,   'r'},
+                {"test",        no_argument,            NULL,   't'},
+                {"verbose",     no_argument,            NULL,   'v'},
+                {"version",     no_argument,            NULL,   'V'},
+                {"help",        no_argument,            NULL,   'h'},
+                {0}
+        };
+        while ((opt = getopt_long(argc, argv, shortopts, longopts, NULL)) != -1) {
+#else
+        while ((opt = getopt(argc, argv, shortopts)) != -1) {
+#endif
+                switch (opt) {
                         case 'c':
-                                Run.controlfile = Str_dup(optarg);
+                        {
+                                char *f = optarg;
+                                if (f[0] != SEPARATOR_CHAR)
+                                        f = File_getRealPath(optarg, (char[PATH_MAX]){});
+                                if (! f)
+                                        THROW(AssertException, "The control file '%s' does not exist at %s",
+                                              Str_trunc(optarg, 80), Dir_cwd((char[STRLEN]){}, STRLEN));
+                                if (! File_isFile(f))
+                                        THROW(AssertException, "The control file '%s' is not a file", Str_trunc(f, 80));
+                                if (! File_isReadable(f))
+                                        THROW(AssertException, "The control file '%s' is not readable", Str_trunc(f, 80));
+                                Run.controlfile = Str_dup(f);
                                 break;
-
+                        }
                         case 'd':
+                        {
                                 Run.isdaemon = TRUE;
                                 sscanf(optarg, "%d", &Run.polltime);
-                                if (Run.polltime<1) {
-                                        LogError("%s: option -%c requires a natural number\n", prog, opt);
+                                if (Run.polltime < 1) {
+                                        LogError("Option -%c requires a natural number\n", opt);
                                         exit(1);
                                 }
                                 break;
-
+                        }
                         case 'g':
+                        {
                                 Run.mygroup = Str_dup(optarg);
                                 break;
-
+                        }
                         case 'l':
+                        {
                                 Run.logfile = Str_dup(optarg);
                                 if (IS(Run.logfile, "syslog"))
                                         Run.use_syslog = TRUE;
                                 Run.dolog = TRUE;
                                 break;
-
+                        }
                         case 'p':
+                        {
                                 Run.pidfile = Str_dup(optarg);
                                 break;
-
+                        }
                         case 's':
+                        {
                                 Run.statefile = Str_dup(optarg);
                                 break;
-
+                        }
                         case 'I':
+                        {
                                 Run.init = TRUE;
                                 break;
-
-                        case 't':
-                                Run.testing = TRUE;
+                        }
+                        case 'i':
+                        {
+                                do_init();
+                                assert(Run.id);
+                                printf("Monit ID: %s\n", Run.id);
+                                exit(0);
                                 break;
-
+                        }
+                        case 'r':
+                        {
+                                do_init();
+                                assert(Run.id);
+                                printf("Reset Monit Id? [Y/N]> ");
+                                if (getchar() == 'Y') {
+                                        File_delete(Run.idfile);
+                                        Util_monitId(Run.idfile);
+                                }
+                                exit(0);
+                                break;
+                        }
+                        case 't':
+                        {
+                                do_init(); // Parses control file and initialize program, exit on error
+                                printf("Control file syntax OK\n");
+                                exit(0);
+                                break;
+                        }
                         case 'v':
+                        {
                                 Run.debug++;
                                 break;
-
+                        }
                         case 'H':
+                        {
                                 if (argc > optind)
                                         Util_printHash(argv[optind]);
                                 else
                                         Util_printHash(NULL);
-
                                 exit(0);
                                 break;
-
+                        }
                         case 'V':
+                        {
                                 version();
                                 exit(0);
                                 break;
-
+                        }
                         case 'h':
+                        {
                                 help();
                                 exit(0);
                                 break;
-
+                        }
                         case '?':
+                        {
                                 switch(optopt) {
-
                                         case 'c':
                                         case 'd':
                                         case 'g':
                                         case 'l':
                                         case 'p':
                                         case 's':
-                                                LogError("%s: option -- %c requires an argument\n", prog, optopt);
+                                        {
+                                                LogError("Option -- %c requires an argument\n", optopt);
                                                 break;
+                                        }
                                         default:
-                                                LogError("%s: invalid option -- %c  (-h will show valid options)\n", prog, optopt);
-
+                                        {
+                                                LogError("Invalid option -- %c  (-h will show valid options)\n", optopt);
+                                        }
                                 }
-
                                 exit(1);
-
+                        }
                 }
-
         }
-
 }
 
 
@@ -715,6 +768,8 @@ static void help() {
         printf(" -p pidfile    Use this lock file in daemon mode\n");
         printf(" -s statefile  Set the file monit should write state information to\n");
         printf(" -I            Do not run in background (needed for run from init)\n");
+        printf(" --id          Print Monit's unique ID\n");
+        printf(" --resetid     Reset Monit's unique ID. Use with caution\n");
         printf(" -t            Run syntax check for the control file\n");
         printf(" -v            Verbose mode, work noisy (diagnostic output)\n");
         printf(" -vv           Very verbose mode, same as -v plus log stacktrace on error\n");
@@ -748,7 +803,7 @@ static void help() {
  */
 static void version() {
         printf("This is Monit version " VERSION "\n");
-        printf("Copyright (C) 2001-2013 Tildeslash Ltd.");
+        printf("Copyright (C) 2001-2014 Tildeslash Ltd.");
         printf(" All Rights Reserved.\n");
 }
 
