@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -61,8 +61,8 @@ int check_socket(int socket);
 
 
 /**
- * Verify that the udp server is up. The given socket must be a 
- * connected udp socket if we should be able to test the udp server. 
+ * Verify that the udp server is up. The given socket must be a
+ * connected udp socket if we should be able to test the udp server.
  * The test is conducted by sending a datagram to the server and
  * check for a returned ICMP error when reading from the socket.
  * @param socket A socket
@@ -76,29 +76,21 @@ int check_udp_socket(int socket);
  * protocol. The protocol should be either SOCK_STREAM or SOCK_DGRAM.
  * @param hostname The host to open a socket at
  * @param port The port number to connect to
- * @param protocol Socket protocol to use (SOCK_STREAM|SOCK_DGRAM)
+ * @param type Socket type to use (SOCK_STREAM|SOCK_DGRAM)
  * @param timeout If not connected within timeout seconds abort and return -1
  * @return The socket or -1 if an error occured.
  */
-int create_socket(const char *hostname, int port, int protocol, int timeout);
-
-
-/**
- * Open a socket using the given Port_T structure. The protocol,
- * destination and type are selected appropriately.
- * @param p connection description
- * @return The socket or -1 if an error occured.
- */
-int create_generic_socket(Port_T p);
+int create_socket(const char *hostname, int port, int type, int timeout);
 
 
 /**
  * Create a non-blocking UNIX socket.
  * @param pathname The pathname to use for the unix socket
+ * @param type Socket type to use (SOCK_STREAM|SOCK_DGRAM)
  * @param timeout If not connected within timeout seconds abort and return -1
  * @return The socket or -1 if an error occured.
  */
-int create_unix_socket(const char *pathname, int timeout);
+int create_unix_socket(const char *pathname, int type, int timeout);
 
 
 /**
@@ -116,30 +108,6 @@ int create_unix_socket(const char *pathname, int timeout);
 int create_server_socket(int port, int backlog, const char *bindAddr);
 
 
-/**
- * Shutdown a socket and close the descriptor.
- * @param socket The socket to shutdown and close
- * @return TRUE if the close succeed otherwise FALSE
- */
-int close_socket(int socket);
-
-
-/**
- * Enable nonblocking i|o on the given socket.
- * @param socket A socket
- * @return TRUE if success, otherwise FALSE
- */
-int set_noblock(int socket);
-
-
-/**
- * Disable nonblocking i|o on the given socket
- * @param socket A socket
- * @return TRUE if success, otherwise FALSE
- */
-int set_block(int socket);
-
-
 /**
  * Check if data is available, if not, wait timeout seconds for data
  * to be present.
@@ -162,7 +130,7 @@ int can_write(int socket, int timeout);
 
 /**
  * Write <code>size</code> bytes from the <code>buffer</code> to the
- * <code>socket</code> 
+ * <code>socket</code>
  * @param socket the socket to write to
  * @param buffer The buffer to write
  * @param size Number of bytes to send
@@ -180,7 +148,7 @@ ssize_t sock_write(int socket, const void *buffer, size_t size, int timeout);
  * @param buffer The buffer to write the data to
  * @param size Number of bytes to read from the socket
  * @param timeout Seconds to wait for data to be available
- * @return The number of bytes read or -1 if an error occured. 
+ * @return The number of bytes read or -1 if an error occured.
 */
 ssize_t sock_read(int socket, void *buffer, int size, int timeout);
 
