@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -77,7 +77,7 @@
 
 
 static int      hz;
-static int      pagesize_kbyte; 
+static int      pagesize_kbyte;
 static long     total_old    = 0;
 static long     cpu_user_old = 0;
 static long     cpu_syst_old = 0;
@@ -178,6 +178,9 @@ int initprocesstree_sysdep(ProcessTree_T ** reference) {
   for (int i = 0; i < treesize; i++) {
     pt[i].pid         = pinfo[i].p_pid;
     pt[i].ppid        = pinfo[i].p_ppid;
+    pt[i].uid         = pinfo[i].p_ruid;
+    pt[i].euid        = pinfo[i].p_uid;
+    pt[i].gid         = pinfo[i].p_rgid;
     pt[i].starttime   = pinfo[i].p_ustart_sec;
     pt[i].cputime     = (long)((pinfo[i].p_rtime_sec * 10) + (pinfo[i].p_rtime_usec / 100000));
     pt[i].cpu_percent = 0;
@@ -284,6 +287,6 @@ int used_system_cpu_sysdep(SystemInfo_T *si) {
   cpu_user_old = cp_time[CP_USER];
   cpu_syst_old = cp_time[CP_SYS];
 
-  return TRUE;  
+  return TRUE;
 }
 
