@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 
@@ -192,6 +192,9 @@ int initprocesstree_sysdep(ProcessTree_T **reference) {
   for (int i = 0; i < treesize; i++) {
     pt[i].pid         = pinfo[i].p_pid;
     pt[i].ppid        = pinfo[i].p_ppid;
+    pt[i].uid         = pinfo[i].p_ruid;
+    pt[i].euid        = pinfo[i].p_uid;
+    pt[i].gid         = pinfo[i].p_rgid;
     pt[i].starttime   = pinfo[i].p_ustart_sec;
     pt[i].cputime     = (long)((pinfo[i].p_rtime_sec * 10) + (pinfo[i].p_rtime_usec / 100000));
     pt[i].cpu_percent = 0;
@@ -302,6 +305,6 @@ int used_system_cpu_sysdep(SystemInfo_T *si) {
   cpu_user_old = cp_time[CP_USER];
   cpu_syst_old = cp_time[CP_SYS];
 
-  return TRUE;  
+  return TRUE;
 }
 
