@@ -19,27 +19,15 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
 
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
-#ifdef HAVE_PCRE
-#include <pcre.h>
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
 
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #ifdef HAVE_REGEX_H
 #include <regex.h>
 #endif
@@ -52,7 +40,7 @@
  *  @file
  */
 int check_generic(Socket_T socket) {
-  Generic_T g= NULL;
+  Generic_T g = NULL;
   char *buf;
 #ifdef HAVE_REGEX_H
   int regex_return;
@@ -69,62 +57,62 @@ int check_generic(Socket_T socket) {
 
     if (g->send != NULL) {
 
-      /* Unescape any \0x00 escaped chars in g's send string 
+      /* Unescape any \0x00 escaped chars in g's send string
       to allow sending a string containing \0 bytes also */
       char *X = Str_dup(g->send);
       int l = Util_handle0Escapes(X);
 
       if(socket_write(socket, X, l) < 0) {
-        socket_setError(socket, "GENERIC: error sending data -- %s\n", STRERROR);
+        socket_setError(socket, "GENERIC: error sending data -- %s", STRERROR);
         FREE(X);
         FREE(buf);
         return FALSE;
       } else
-        DEBUG("GENERIC: successfully sent: '%s'\n", g->send); 
+        DEBUG("GENERIC: successfully sent: '%s'\n", g->send);
 
-      FREE(X);          
+      FREE(X);
 
     } else if (g->expect != NULL) {
-      int n; 
+      int n;
 
       /* Need read, not readln here */
-      if((n= socket_read(socket, buf, Run.expectbuffer))<0) {
-        socket_setError(socket, "GENERIC: error receiving data -- %s\n", STRERROR);
+      if((n = socket_read(socket, buf, Run.expectbuffer))<0) {
+        socket_setError(socket, "GENERIC: error receiving data -- %s", STRERROR);
         FREE(buf);
         return FALSE;
       }
-      buf[n]= 0;
+      buf[n] = 0;
 
 #ifdef HAVE_REGEX_H
-      regex_return= regexec(g->expect, buf, 0, NULL, 0);
+      regex_return = regexec(g->expect, buf, 0, NULL, 0);
       if (regex_return != 0) {
         char e[STRLEN];
         regerror(regex_return, g->expect, e, STRLEN);
-        socket_setError(socket, "GENERIC: receiving unexpected data [%s] -- %s\n", Str_trunc(buf, STRLEN - 4), e);
+        socket_setError(socket, "GENERIC: receiving unexpected data [%s] -- %s", Str_trunc(buf, STRLEN - 4), e);
         FREE(buf);
         return FALSE;
       } else
-        DEBUG("GENERIC: successfully received: '%s'\n", Str_trunc(buf, STRLEN - 4)); 
+        DEBUG("GENERIC: successfully received: '%s'\n", Str_trunc(buf, STRLEN - 4));
 
 #else
       /* w/o regex support */
 
       if (strncmp(buf, g->expect, strlen(g->expect)) != 0) {
-        socket_setError(socket, "GENERIC: receiving unexpected data [%s]\n", Str_trunc(buf, STRLEN - 4));
+        socket_setError(socket, "GENERIC: receiving unexpected data [%s]", Str_trunc(buf, STRLEN - 4));
         FREE(buf);
         return FALSE;
       } else
-        DEBUG("GENERIC: successfully received: '%s'\n", Str_trunc(buf, STRLEN - 4)); 
+        DEBUG("GENERIC: successfully received: '%s'\n", Str_trunc(buf, STRLEN - 4));
 
 #endif
 
     } else {
       /* This should not happen */
-      socket_setError(socket, "GENERIC: unexpected strangeness\n");
+      socket_setError(socket, "GENERIC: unexpected strangeness");
       FREE(buf);
       return FALSE;
     }
-    g= g->next;
+    g = g->next;
   }
 
   FREE(buf);
