@@ -19,34 +19,23 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
 
-#ifdef HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
-#ifdef HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
 
-#include <netinet/in.h>
-#include <time.h>
+#ifdef HAVE_ARPA_INET_H
+#include <arpa/inet.h>
+#endif
 
 #include "protocol.h"
 
 /**
- *  Check the server response, check the time it returns and accept a 
+ *  Check the server response, check the time it returns and accept a
  *  TIME_TOLERANCE sec delta with the current system time.
  *
  *  This test is based on RFC868. Rdate returns number of seconds since
@@ -63,11 +52,11 @@ int check_rdate(Socket_T socket) {
   time_t delta;
   time_t rdatet;
   time_t systemt;
-	  
+
   ASSERT(socket);
 
   if(socket_read(socket,(char*) &rdatet, sizeof(time_t)) <= 0) {
-    socket_setError(socket, "RDATE: error receiving data -- %s\n", STRERROR);
+    socket_setError(socket, "RDATE: error receiving data -- %s", STRERROR);
     return FALSE;
   }
 
@@ -75,17 +64,17 @@ int check_rdate(Socket_T socket) {
   rdatet = ntohl(rdatet) - TIME_OFFSET;
 
   if((systemt = time(NULL)) == -1) {
-    socket_setError(socket, "RDATE error: cannot get system time -- %s\n", STRERROR);
+    socket_setError(socket, "RDATE error: cannot get system time -- %s", STRERROR);
     return FALSE;
   }
 
   if(rdatet >= systemt)
     delta = (rdatet-systemt);
   else
-    delta= (systemt-rdatet);
+    delta = (systemt-rdatet);
 
   if(delta > TIME_TOLERANCE) {
-    socket_setError(socket, "RDATE error: time does not match system time -- %s\n", STRERROR);
+    socket_setError(socket, "RDATE error: time does not match system time -- %s", STRERROR);
     return FALSE;
   }
 
