@@ -19,19 +19,11 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
 
-#ifdef HAVE_STDIO_H
-#include <stdio.h>
-#endif
-
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
@@ -55,8 +47,8 @@ int check_smtp(Socket_T socket) {
         ASSERT(socket);
 
         /* Try HELO also before giving up as of rfc2821 4.1.1.1 */
-        if (expect(socket, 220, TRUE) 
-            && ((say(socket, "EHLO localhost\r\n") && expect(socket, 250, FALSE)) || (say(socket, "HELO localhost\r\n") && expect(socket, 250, TRUE))) 
+        if (expect(socket, 220, TRUE)
+            && ((say(socket, "EHLO localhost\r\n") && expect(socket, 250, FALSE)) || (say(socket, "HELO localhost\r\n") && expect(socket, 250, TRUE)))
             && (say(socket, "QUIT\r\n") && expect(socket, 221, TRUE)))
                 return TRUE;
 
@@ -69,7 +61,7 @@ int check_smtp(Socket_T socket) {
 
 static int say(Socket_T socket, char *msg) {
         if (socket_write(socket, msg, strlen(msg)) < 0) {
-                socket_setError(socket, "SMTP: error sending data -- %s\n", STRERROR);
+                socket_setError(socket, "SMTP: error sending data -- %s", STRERROR);
                 return FALSE;
         }
         return TRUE;
@@ -82,14 +74,14 @@ static int expect(Socket_T socket, int expect, int log) {
 
         do {
                 if (! socket_readln(socket, buf, STRLEN)) {
-                        socket_setError(socket, "SMTP: error receiving data -- %s\n", STRERROR);
+                        socket_setError(socket, "SMTP: error receiving data -- %s", STRERROR);
                         return FALSE;
                 }
                 Str_chomp(buf);
         } while (buf[3] == '-'); // Discard multi-line response
         if (sscanf(buf, "%d", &status) != 1) {
-                if(log) 
-                        socket_setError(socket, "SMTP error: %s\n", buf);
+                if(log)
+                        socket_setError(socket, "SMTP error: %s", buf);
                 return FALSE;
         }
         return TRUE;
