@@ -19,7 +19,7 @@
  * including the two.
  *
  * You must obey the GNU Affero General Public License in all respects
- * for all of the code used other than OpenSSL.  
+ * for all of the code used other than OpenSSL.
  */
 
 #include "config.h"
@@ -34,11 +34,11 @@
 
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
-#endif 
+#endif
 
 #ifdef HAVE_SIGNAL_H
 #include <signal.h>
-#endif 
+#endif
 
 #ifdef HAVE_STRING_H
 #include <string.h>
@@ -135,7 +135,7 @@ void spawn(Service_T S, command_t C, Event_T E) {
         pid_t pid;
         sigset_t mask;
         sigset_t save;
-        int stat_loc= 0;
+        int stat_loc = 0;
         int exit_status;
         char date[42];
 
@@ -155,10 +155,10 @@ void spawn(Service_T S, command_t C, Event_T E) {
         pthread_sigmask(SIG_BLOCK, &mask, &save);
 
         Time_string(Time_now(), date);
-        pid= fork();
+        pid = fork();
         if(pid < 0) {
-                LogError("Cannot fork a new process\n");  
-                exit(1); 
+                LogError("Cannot fork a new process -- %s\n", STRERROR);
+                exit(1);
         }
 
         if(pid == 0) {
@@ -227,7 +227,7 @@ void spawn(Service_T S, command_t C, Event_T E) {
                 LogError("Waitpid error\n");
         }
 
-        exit_status= WEXITSTATUS(stat_loc);
+        exit_status = WEXITSTATUS(stat_loc);
         if (exit_status & setgid_ERROR)
                 LogError("Failed to change gid to '%d' for '%s'\n", C->gid, C->arg[0]);
         if (exit_status & setuid_ERROR)
@@ -247,4 +247,4 @@ void spawn(Service_T S, command_t C, Event_T E) {
          * the init system-process will wait for it. So we just return
          */
 
-} 
+}
